==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/File/src/Do/Do.FilesAndFolders/Plugin.cs <==
/* Plugin.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;

using Do.Platform;
using Do.Universe;
using Do.Universe.Common;

namespace Do.FilesAndFolders
{

	static class Plugin
	{
		public static IndexedFolderCollection FolderIndex { get; private set; }
		public static FilesAndFoldersPreferences Preferences { get; private set; }
		public static ImportantFolders ImportantFolders { get; private set; }
		
		static Plugin ()
		{
			try {
				Preferences = new FilesAndFoldersPreferences ();
				ImportantFolders = new ImportantFolders ();
				FolderIndex = new IndexedFolderCollection ();

				FolderIndex.Initialize ();
			} catch (Exception e) {
				Log.Error ("Files and folders plugin failed to initialize: {0}", e.Message);
				Log.Debug (e.StackTrace);
			}
		}

		public static IFileItem NewFileItem (string path)
		{
			return Services.UniverseFactory.NewFileItem (path);
		}

		public static IApplicationItem NewApplicationItem (string path)
		{
			return Services.UniverseFactory.NewApplicationItem (path);
		}

		public static ITextItem NewTextItem (string text)
		{
			return new TextItem (text);
		}
	}
}

==> gnome-do-plugins_0.8.2.1+dfsg.orig.tar.gz: gnome-do-plugins-0.8.2.1/File/src/Do/Do.FilesAndFolders/Plugin.cs <==
/* Plugin.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Text.RegularExpressions;

using Do.Platform;
using Do.Universe;
using Do.Universe.Common;

namespace Do.FilesAndFolders
{

	static class Plugin
	{
		public static IndexedFolderCollection FolderIndex { get; private set; }
		public static FilesAndFoldersPreferences Preferences { get; private set; }
		public static ImportantFolders ImportantFolders { get; private set; }
		
		static Plugin ()
		{
			try {
				Preferences = new FilesAndFoldersPreferences ();
				ImportantFolders = new ImportantFolders ();
				FolderIndex = new IndexedFolderCollection ();

				FolderIndex.Initialize ();
			} catch (Exception e) {
				Log.Error ("Files and folders plugin failed to initialize: {0}", e.Message);
				Log.Debug (e.StackTrace);
			}
		}

		public static IFileItem NewFileItem (string path)
		{
			return Services.UniverseFactory.NewFileItem (UnwrapHomeFolder (path));
		}

		public static IApplicationItem NewApplicationItem (string path)
		{
			return Services.UniverseFactory.NewApplicationItem (path);
		}

		public static ITextItem NewTextItem (string text)
		{
			return new TextItem (text);
		}

		public static string UnwrapHomeFolder (string path)
		{
			return Regex.Replace (path, @"^~\/", ImportantFolders.UserHome + "/");
		}
	}
}
